import type { ExtractPropTypes, InjectionKey, PropType, SetupContext, Ref } from 'vue';
import type { DiffFile } from 'diff2html/lib/types';
export declare type OutputFormat = 'line-by-line' | 'side-by-side';
export declare type ExpandDirection = 'up' | 'down' | 'updown' | 'all';
export declare type LineSide = 'left' | 'right';
export interface CommentPosition {
    left: number;
    right: number;
}
export interface CodeReviewMethods {
    toggleFold: (status?: boolean) => void;
    insertComment: (lineNumber: number, lineSide: LineSide, commentDom: HTMLElement) => void;
    removeComment: (lineNumber: number, lineSide: LineSide) => void;
}
export declare const codeReviewProps: {
    diff: {
        type: StringConstructor;
        required: boolean;
        default: string;
    };
    fold: {
        type: BooleanConstructor;
        default: boolean;
    };
    outputFormat: {
        type: PropType<OutputFormat>;
        default: string;
    };
    expandAllThreshold: {
        type: NumberConstructor;
        default: number;
    };
};
export declare type CodeReviewProps = ExtractPropTypes<typeof codeReviewProps>;
export interface CodeReviewContext {
    reviewContentRef: Ref<HTMLElement>;
    diffInfo: DiffFile;
    isFold: Ref<boolean>;
    rootCtx: SetupContext;
}
export declare const CodeReviewInjectionKey: InjectionKey<CodeReviewContext>;
